@@ -1,7 +1,7 @@
 ALLOWED_DOMAINS = []
 
 IUNO_SITE_DOMAIN_NAMES = {
-    DEVELOPMENT: '127.0.0.1:8000', #FIXME
+    DEVELOPMENT: '127.0.0.1:8000',
     STAGE: '127.0.0.1:8000', #FIXME
-    PRODUCTION: '127.0.0.1:8000', 
+    PRODUCTION: '127.0.0.1:8000', #FIXME
 }
\ No newline at end of file
