@@ -1,10 +1,6 @@
 #!/bin/sh
 
 {% if useConda %}
-pip uninstall django --yes
-rm -rf /home/nuwa/app/lib/python3.6/site-packages/django/
-pip install django==1.11.20
-
 if [ -z $VIRTUAL_ENV ]; then
     python -m pip install --upgrade pip
     pip install -r REQUIREMENTS.txt
