@@ -1,9 +1,11 @@
-INSTALLED_APPS = (
+INSTALLED_APPS = [
     'django.contrib.admin',
     'django.contrib.auth',
     'django.contrib.contenttypes',
     'django.contrib.sessions',
     'django.contrib.messages',
     'django.contrib.staticfiles',
+    'django.contrib.sites',
     'Iuno.scaffold',
-)
\ No newline at end of file
+    '{{ name }}',
+]
\ No newline at end of file
