@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11422 2019-04-03 14:03:52Z Lavender $
+# $Id: admin.py 11449 2019-04-13 12:42:08Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-03 23:03:52 +0900 (週三, 03 四月 2019) $
-# $Revision: 11422 $
+# $Date: 2019-04-13 21:42:08 +0900 (週六, 13 四月 2019) $
+# $Revision: 11449 $
 
 import os
 import datetime
@@ -40,6 +40,7 @@ from django.core.urlresolvers import reverse
 # ------------------------------------------------------------------------------
 from Iuno.template_editor.models import Static, Template, Version, FOLDER, FILE
 from Iuno.template_editor import BACKUP_FILE_DIR, toBytes
+from Iuppiter.Logging import createLogger
 
 TEXT_SUB_FILE_NAME = [
     'txt', 'css', 'js', 'html', 'htm',
@@ -49,6 +50,7 @@ IMAGE_SUB_FILE_NAME = [
     'jpg', 'png', 'jpeg', 'bmp', 'gif', 'tif',
 ]
 
+logger = createLogger(__name__)
 
 class FolderFrom(forms.ModelForm):
     class Meta(object):
@@ -171,6 +173,9 @@ def checkVersion(model):
         for version in Version.objects.filter(
             dirName=dirName, conflict=True):
             conflictNodeList.append((node, version))
+            logger.info(
+                "%s conflict: version %d and version %s" % (
+                path, version.number, version.preVersion.number))
 
     return conflictNodeList
 
@@ -300,19 +305,18 @@ class BaseFileAdmin(admin.ModelAdmin):
 
         if obj.type == FILE:
             subFileName = obj.subFileName
+            fullPath = obj.absolutePath
 
             if subFileName in TEXT_SUB_FILE_NAME:
                 # 能支援上傳修改檔案
                 content = request.POST.get('content')
                 
-                fullPath = obj.absolutePath
                 with open(fullPath, 'wb') as f:
                     data = f.write(content.encode('utf-8'))
             elif subFileName in IMAGE_SUB_FILE_NAME:
                 # 圖片轉檔
                 image = request.FILES.get('image')
-                fullPath = obj.absolutePath
-
+                
                 if image:
                     data = image.read()
                     image.close()
@@ -323,12 +327,12 @@ class BaseFileAdmin(admin.ModelAdmin):
                     backupPath = version.absoluteBackupPath
                     with open(backupPath, 'rb') as f:
                         data = f.read()
-                    fullPath = obj.absolutePath
+                    
                     with open(fullPath, 'wb') as f:
                         data = f.write(data)
                 else:
                     pass
-            
+            logger.info("File has modified: %s" % obj.path)
             version = createVersion(self.model, obj)
 
         return super(BaseFileAdmin, self).response_change(request, obj)
